/*****************************************************************************
/*
/*            INSTITUTO NACIONAL PARA LA EVALUACIN DE LA EDUCACIN
/*                       DIRECCIN DE PRUEBAS Y MEDICIN
/*                           SUBDIRECCION DE ANLISIS
/*_____________________________________________________________________________
/*
/*            EXAMENES DE LA CALIDAD Y EL LOGRO EDUCATIVOS (Excale)
/*                TERCER GRADO DE PREESCOLAR (Excale 00)
/*
/*                      **** LENGUAJE Y COMUNICACIN ****
/*
/*                     Ciclo escolar evaluado: 2006 - 2007
/*_____________________________________________________________________________
/*
/*
/*       PROGRAMA PARA CONSTRUIR LA BASE DE DATOS DE ALUMNOS DE LENGUAJE Y
/*                          COMUNICACIN EN FORMATO SAS
/*_____________________________________________________________________________
/*
/*  El programa convierte el archivo Excale00_2007_Alum_LC.txt el cual est en
/*  formato ASCII a una base de datos en formato SAS. El programa realiza las
/*  siguientes tareas:
/*   - Declara formatos para algunas variables
/*   - Lee las variables del archivo en formato ASCII
/*   - Declara los valores considerados en el anlisis como perdidos (missing values)
/*
/* INSTRUCCIONES
/*  Para construir la base de datos (tabla de datos) es necesario:
/*      1) Crear una carpeta de trabajo y colocar en ella al archivo Excale00_2007_Alum_LC.txt
/*         as como el archivo Excale00_2007_Alum_LC.SAS (este archivo) los cules se pueden
/*         descargar del sitio web del INEE (www.inee.edu.mx).
/*      2) Modificar la primera y segunda lnea de los comandos de este archivo
/*         (libname y filename) para actualizar el nombre de la librera y el archivo
/*         de trabajo.
/*      3) Ejecutar el programa del archivo.
/*
/*  Al finalizar, se deber contar con la base de datos (tabla de datos) Excale00_2007_Alum_LC.sas7bdat
/*
/*  Posteriormente, cuando se desee utilizar nuevamente la base Excale00_2007_Alum_LC.sas7bdat,
/*  se deber ejecutar primero el procedimiento FORMAT ("proc FORMAT") de este programa para que
/*  SAS cargue los formatos necesarios para abrir la base.
/*
/* CONTACTO:
/*
/*      Para mayor informacin o aclaracin de dudas favor de contactar a la
/*      Subdireccin de Anlisis del Instituto
/*      Correo electrnico: excale.analisis@inee.edu.mx
/*      Tel 5482 0900 Ext. 1082
/*      Domicilio: Jos Ma. Velasco No. 101. 3er piso. Col. San Jos Insurgentes
/*                 Del. Benito Jurez. Mxico. D.F.
/*
/* FECHA DE LIBERACIN: 5 DE AGOSTO DE 2008
/*
/*  ****************************************************************************/


LIBNAME  INEE  "C:\***\";
FILENAME alum  "C:\***\Excale00_2007_Alum_LC.TXT";

PROC FORMAT;
     VALUE id_entF     1         ="Aguascalientes"
                       2         ="Baja California"
                       3         ="Baja California Sur"
                       4         ="Campeche"
                       5         ="Coahuila"
                       6         ="Colima"
                       7         ="Chiapas"
                       8         ="Chihuahua"
                       9         ="Distrito Federal"
                       10        ="Durango"
                       11        ="Guanajuato"
                       12        ="Guerrero"
                       13        ="Hidalgo"
                       14        ="Jalisco"
                       15        ="Mxico"
                       16        ="Michoacn"
                       17        ="Morelos"
                       18        ="Nayarit"
                       19        ="Nuevo Len"
                       20        ="Oaxaca"
                       21        ="Puebla"
                       22        ="Quertaro"
                       23        ="Quintana Roo"
                       24        ="San Luis Potos"
                       25        ="Sinaloa"
                       26        ="Sonora"
                       27        ="Tabasco"
                       28        ="Tamaulipas"
                       29        ="Tlaxcala"
                       30        ="Veracruz"
                       31        ="Yucatn"
                       32        ="Zacatecas";
     VALUE id_modF     1         ="Urbano Pblico"
                       2         ="Rural Pblico"
                       3         ="Educacin Indgena"
                       4         ="Cursos Comunitarios"
                       5         ="Privados";
     VALUE $modF       "UP"      ="Urbano Pblico"
                       "RP"      ="Rural Pblico"
                       "EI"      ="Educacin Indgena"
                       "CC"      ="Cursos Comunitarios"
                       "UPV"     ="Privados";
     VALUE sexoF       1         ="Hombre"
                       2         ="Mujer"
                       8         ="Respuesta mltiple"
                       9         ="Respuesta omitida";
     VALUE edadF       99        ="Respuesta omitida";
     VALUE edadcF      1         ="Cuatro aos o menos"
                       2         ="Cinco aos"
                       3         ="Seis aos"
                       4         ="Siete aos o ms"
                       9         ="Respuesta omitida";
     VALUE edad1sF     99        ="Respuesta omitida";
     VALUE edad1scF    1         ="Cuatro aos o menos"
                       2         ="Cinco aos"
                       3         ="Seis o ms aos"
                       9         ="Respuesta omitida";
     VALUE edadnF      1         ="Edad normativa"
                       2         ="Extra-edad"
                       9         ="Respuesta omitida";
     VALUE edad_acF    98        ="Respuesta mltiple"
                       99        ="Respuesta omitida";
     VALUE mes_nacF    1         ="Enero"
                       2         ="Febrero"
                       3         ="Marzo"
                       4         ="Abril"
                       5         ="Mayo"
                       6         ="Junio"
                       7         ="Julio"
                       8         ="Agosto"
                       9         ="Septiembre"
                       10        ="Octubre"
                       11        ="Noviembre"
                       12        ="Diciembre"
                       98        ="Respuesta mltiple"
                       99        ="Respuesta omitida";
     VALUE docenteF    99999     ="Respuesta omitida";
     VALUE ela1_10F
                       0         ="Fallo"
                       1         ="Acierto (pregunta dicotmica)/Acierto parcial (Pregunta politmica)"
                       2         ="Acierto total (pregunta dicotmica)"
                       5         ="Respuesta invlida (El alumno copi la respuesta a sus compaeros)"
                       7         ="Reactivo no administrado (No se incluy en su cuadernillo de examen)";
RUN;



DATA INEE.Excale00_2007_Alum_LC;
   LENGTH
       nacional           3
       escuela            4
       id_ent             3
       nom_ent            $19
       id_mod             3
       mod                $4
       entest             $6
       alumno             6
       id_instr           $15
       sexo               3
       EDAD               8
       EDADC              3
       Edad1sep           8
       Edad1SepC          3
       EDADN              3
       edad_ac            3
       mes_nac            3
       w_alu              8
       docente            5
       ela_01             3
       ela_02             3
       ela_03             3
       ela_04             3
       ela_05             3
       ela_06             3
       ela_07             3
       ela_08             3
       ela_09             3
       elb_01             3
       elb_02             3
       elb_03             3
       elb_04             3
       elb_05             3
       elb_06             3
       elb_07             3
       elb_08             3
       elb_09             3
       elc_01             3
       elc_02             3
       elc_03             3
       elc_04             3
       elc_05             3
       elc_06             3
       elc_07             3
       elc_08             3
       elc_09             3
       eld_01             3
       eld_02             3
       eld_03             3
       eld_04             3
       eld_05             3
       eld_06             3
       eld_07             3
       eld_08             3
       eld_09             3
       eld_10             3
       pv1Esp             8
       pv2Esp             8
       pv3Esp             8
       pv4Esp             8
       pv5Esp             8
       Espnvl1            3
       Espnvl2            3
       Espnvl3            3
       Espnvl4            3
       Espnvl5            3
       Espnvlb1           3
       Espnvlb2           3
       Espnvlb3           3
       Espnvlb4           3
       Espnvlb5           3
       wvarstrr           3
       w_fstr1            8
       w_fstr2            8
       w_fstr3            8
       w_fstr4            8
       w_fstr5            8
       w_fstr6            8
       w_fstr7            8
       w_fstr8            8
       w_fstr9            8
       w_fstr10           8
       w_fstr11           8
       w_fstr12           8
       w_fstr13           8
       w_fstr14           8
       w_fstr15           8
       w_fstr16           8
       w_fstr17           8
       w_fstr18           8
       w_fstr19           8
       w_fstr20           8
       w_fstr21           8
       w_fstr22           8
       w_fstr23           8
       w_fstr24           8
       w_fstr25           8
       w_fstr26           8
       w_fstr27           8
       w_fstr28           8
       w_fstr29           8
       w_fstr30           8
       w_fstr31           8
       w_fstr32           8
       w_fstr33           8
       w_fstr34           8
       w_fstr35           8
       w_fstr36           8
       w_fstr37           8
       w_fstr38           8
       w_fstr39           8
       w_fstr40           8
       w_fstr41           8
       w_fstr42           8
       w_fstr43           8
       w_fstr44           8
       w_fstr45           8
       w_fstr46           8
       w_fstr47           8
       w_fstr48           8
       w_fstr49           8
       w_fstr50           8
       w_fstr51           8
       w_fstr52           8
       w_fstr53           8
       w_fstr54           8
       w_fstr55           8
       w_fstr56           8
       w_fstr57           8
       w_fstr58           8
       w_fstr59           8
       w_fstr60           8
       w_fstr61           8
       w_fstr62           8
       w_fstr63           8
       w_fstr64           8
       w_fstr65           8
       w_fstr66           8
       w_fstr67           8
       w_fstr68           8
       w_fstr69           8
       w_fstr70           8
       w_fstr71           8
       w_fstr72           8
       w_fstr73           8
       w_fstr74           8
       w_fstr75           8
       w_fstr76           8
       w_fstr77           8
       w_fstr78           8
       w_fstr79           8
       w_fstr80           8
   ;

INFILE alum MISSOVER LINESIZE = 1087;
   INPUT
        nacional             1 - 1
        escuela              2 - 5
        id_ent               6 - 7
        nom_ent              8 - 26
        id_mod              27 - 27
        mod                 28 - 31
        entest              32 - 37
        alumno              38 - 42
        id_instr            43 - 57
        sexo                58 - 58
        EDAD                59 - 69
        EDADC               70 - 70
        Edad1sep            71 - 81
        Edad1SepC           82 - 82
        EDADN               83 - 83
        edad_ac             84 - 85
        mes_nac             86 - 87
        w_alu               88 - 98
        docente             99 - 103
        ela_01             104 - 104
        ela_02             105 - 105
        ela_03             106 - 106
        ela_04             107 - 107
        ela_05             108 - 108
        ela_06             109 - 109
        ela_07             110 - 110
        ela_08             111 - 111
        ela_09             112 - 112
        elb_01             113 - 113
        elb_02             114 - 114
        elb_03             115 - 115
        elb_04             116 - 116
        elb_05             117 - 117
        elb_06             118 - 118
        elb_07             119 - 119
        elb_08             120 - 120
        elb_09             121 - 121
        elc_01             122 - 122
        elc_02             123 - 123
        elc_03             124 - 124
        elc_04             125 - 125
        elc_05             126 - 126
        elc_06             127 - 127
        elc_07             128 - 128
        elc_08             129 - 129
        elc_09             130 - 130
        eld_01             131 - 131
        eld_02             132 - 132
        eld_03             133 - 133
        eld_04             134 - 134
        eld_05             135 - 135
        eld_06             136 - 136
        eld_07             137 - 137
        eld_08             138 - 138
        eld_09             139 - 139
        eld_10             140 - 140
        pv1Esp             141 - 151
        pv2Esp             152 - 162
        pv3Esp             163 - 173
        pv4Esp             174 - 184
        pv5Esp             185 - 195
        Espnvl1            196 - 196
        Espnvl2            197 - 197
        Espnvl3            198 - 198
        Espnvl4            199 - 199
        Espnvl5            200 - 200
        Espnvlb1           201 - 201
        Espnvlb2           202 - 202
        Espnvlb3           203 - 203
        Espnvlb4           204 - 204
        Espnvlb5           205 - 205
        wvarstrr           206 - 207
        w_fstr1            208 - 218
        w_fstr2            219 - 229
        w_fstr3            230 - 240
        w_fstr4            241 - 251
        w_fstr5            252 - 262
        w_fstr6            263 - 273
        w_fstr7            274 - 284
        w_fstr8            285 - 295
        w_fstr9            296 - 306
        w_fstr10           307 - 317
        w_fstr11           318 - 328
        w_fstr12           329 - 339
        w_fstr13           340 - 350
        w_fstr14           351 - 361
        w_fstr15           362 - 372
        w_fstr16           373 - 383
        w_fstr17           384 - 394
        w_fstr18           395 - 405
        w_fstr19           406 - 416
        w_fstr20           417 - 427
        w_fstr21           428 - 438
        w_fstr22           439 - 449
        w_fstr23           450 - 460
        w_fstr24           461 - 471
        w_fstr25           472 - 482
        w_fstr26           483 - 493
        w_fstr27           494 - 504
        w_fstr28           505 - 515
        w_fstr29           516 - 526
        w_fstr30           527 - 537
        w_fstr31           538 - 548
        w_fstr32           549 - 559
        w_fstr33           560 - 570
        w_fstr34           571 - 581
        w_fstr35           582 - 592
        w_fstr36           593 - 603
        w_fstr37           604 - 614
        w_fstr38           615 - 625
        w_fstr39           626 - 636
        w_fstr40           637 - 647
        w_fstr41           648 - 658
        w_fstr42           659 - 669
        w_fstr43           670 - 680
        w_fstr44           681 - 691
        w_fstr45           692 - 702
        w_fstr46           703 - 713
        w_fstr47           714 - 724
        w_fstr48           725 - 735
        w_fstr49           736 - 746
        w_fstr50           747 - 757
        w_fstr51           758 - 768
        w_fstr52           769 - 779
        w_fstr53           780 - 790
        w_fstr54           791 - 801
        w_fstr55           802 - 812
        w_fstr56           813 - 823
        w_fstr57           824 - 834
        w_fstr58           835 - 845
        w_fstr59           846 - 856
        w_fstr60           857 - 867
        w_fstr61           868 - 878
        w_fstr62           879 - 889
        w_fstr63           890 - 900
        w_fstr64           901 - 911
        w_fstr65           912 - 922
        w_fstr66           923 - 933
        w_fstr67           934 - 944
        w_fstr68           945 - 955
        w_fstr69           956 - 966
        w_fstr70           967 - 977
        w_fstr71           978 - 988
        w_fstr72           989 - 999
        w_fstr73          1000 - 1010
        w_fstr74          1011 - 1021
        w_fstr75          1022 - 1032
        w_fstr76          1033 - 1043
        w_fstr77          1044 - 1054
        w_fstr78          1055 - 1065
        w_fstr79          1066 - 1076
        w_fstr80          1077 - 1087
;

   LABEL
       nacional    = "Variable auxiliar para obtener promedios nacionales"
       escuela     = "Identificador de la escuela"
       id_ent      = "Entidad federativa (identificador numrico)"
       nom_ent     = "Entidad federativa"
       id_mod      = "Estrato escolar o Modalidad educativa (identificador numrico)"
       mod         = "Estrato escolar o Modalidad educativa"
       entest      = "Estratos del diseo muestral con el que se estiman los parmetros y errores estndar (Entidad federativa-Modalidad-Densidad de poblacin)"
       alumno      = "Identificador del alumno"
       id_instr    = "Identificador del cuadernillo de examen"
       sexo        = "Sexo del alumno"
       EDAD        = "Edad del alumno al mes de mayo de 2007, en aos (al momento de la aplicacin)"
       EDADC       = "Edad del alumno al mes de mayo de 2007, codificada (al momento de la aplicacin)"
       Edad1sep    = "Edad del alumno al mes de septiembre de 2006, en aos (al inicio del ciclo escolar)"
       Edad1SepC   = "Edad del alumno al mes de septiembre de 2006, codificada (al inicio del ciclo escolar)"
       EDADN       = "Edad normativa"
       edad_ac     = "Edad en aos cumplidos (al momento de la aplicacin)"
       mes_nac     = "Mes de nacimiento del alumno"
       w_alu       = "Peso muestral o ponderador del alumno"
       docente     = "Identificador del docente que imparte clases al alumno"
       ela_01      = "Da informacin sobre su nombre."
       ela_02      = "Reconoce su nombre escrito."
       ela_03      = "Reconoce el nombre de alguno de sus compaeros:  'lee' el nombre solicitado."
       ela_04      = "Evoca sucesos o eventos y habla sobre ellos haciendo referencias espacio-temporales adecuadas a la situacin. / Usa los referentes qu, cundo, dnde y quines en su relato."
       ela_05      = "Describe con algunos detalles dos o ms elementos (personas, personajes, objetos, lugares o fenmenos) distintivos o esenciales de la lmina ilustrativa de un cuento."
       ela_06      = "Narra cuentos siguiendo la secuencia y el orden de las ideas: establece secuencia y coherencia a su narracin y la enriquece con una descripcin y/o un dilogo."
       ela_07      = "Usa recursos del texto literario en sus narraciones."
       ela_08      = "Explica (repite, dice, parafrasea...) dos o los tres elementos bsicos (tarea a realizar, forma de organizarse y producto esperado) que constituyen una instruccin."
       ela_09      = "Comprende instrucciones para realizar una actividad."
       elb_01      = "Manifiesta su(s) preferencia(s) y ofrece explicaciones que la(s) sustentan."
       elb_02      = "Diferencia diversos portadores de texto a partir de sus caractersticas grficas y del lenguaje que se usa en cada uno."
       elb_03      = "Justifica las interpretaciones que hizo acerca del contenido de un texto."
       elb_04      = "Identifica que se lee en el texto escrito y no en las ilustraciones."
       elb_05      = "Identifica que se lee de izquierda a derecha."
       elb_06      = "Identifica que se lee de arriba hacia abajo."
       elb_07      = "Da informacin acerca del valor sonoro de alguna letra."
       elb_08      = "Da informacin acerca del nombre y forma grfica de algunas letras."
       elb_09      = "Da informacin acerca del nombre y orden de algunas letras."
       elc_01      = "Escribe su nombre (nombre de pila, apellido o diminutivo) con la cantidad total de letras y trazos claros y muy parecidos a las letras convencionales (sin importar ortografa o inversin de letras)."
       elc_02      = "Escribe una palabra que comienza con la letra o slaba inicial de su nombre, lo cual contempla: cantidad total de letras (o ms de la mitad) y trazos claros y muy parecidos a los convencionales."
       elc_03      = "Recuerda las actividades que ha realizado y las explica usando, por lo menos, dos acciones unidas por un conector de secuencia y dando un detalle por accin expresada."
       elc_04      = "Identifica algunas partes de los textos (portada, ttulo, ilustraciones y texto)."
       elc_05      = "Expresa sus ideas acerca del contenido de un cuento cuya lectura escuchar: anticipacin global lgica (o factible) expresada en una o ms oraciones en las que incluye, por lo menos, dos ideas relacionadas."
       elc_06      = "Escucha la lectura de fragmentos de un cuento y dice qu cree que suceder: hace una anticipacin especfica elaborada, lgica y pertinente al momento y al contenido del texto."
       elc_07      = "Escucha la narracin de un cuento, expresa qu sucesos o pasajes le provocan alegra, miedo, tristeza..., y fundamenta su sentir dando, por lo menos, un detalle relacionado."
       elc_08      = "Asigna atributos (fsicos o emocionales) a los personajes: se trata de inferencias lgicas o factibles que se derivan de las acciones de los personajes de un cuento."
       elc_09      = "Comenta con otros el contenido de un cuento: da su opinin sobre un personaje o punto en particular y la justifica usando informacin derivada del cuento y/o de su experiencia personal."
       eld_01      = "Reconoce la relacin que existe entre la letra inicial de su nombre y el sonido inicial correspondiente, y establece relaciones con otras palabras."
       eld_02      = "Da informacin sobre su familia: menciona con quines vive y agrega informacin adicional (parentesco, nombres, ocupacin)."
       eld_03      = "Selecciona textos de acuerdo con un propsito lector."
       eld_04      = "Intercambia opiniones y explica o justifica por qu est de acuerdo o en desacuerdo con lo que otros opinan sobre un tema."
       eld_05      = "Identifica la funcin que tienen algunos elementos grficos (palabras, ilustraciones o nmeros)."
       eld_06      = "Identifica la rima en conjuntos de palabras."
       eld_07      = "Establece comparaciones entre las caractersticas grficas de palabras (Ej. Aqu dice <palabra modelo>.  Ahora tacha la palabra <se dicta la palabra a elegir>)."
       eld_08      = "Establece comparaciones entre las caractersticas grficas de palabras (Ej. Tacha la palabra que empieza con las mismas letras de <palabra modelo>)."
       eld_09      = "Reconoce caractersticas de las palabras y letras (con cul termina / con cul empieza)."
       eld_10      = "Reconoce caractersticas de las palabras y letras (tiene la de...)."
       pv1Esp      = "Primer valor plausible de Espaol"
       pv2Esp      = "Segundo valor plausible de Espaol"
       pv3Esp      = "Tercer valor plausible de Espaol"
       pv4Esp      = "Cuarto valor plausible de Espaol"
       pv5Esp      = "Quinto valor plausible de Espaol"
       Espnvl1     = "Nivel de logro en Espaol. Asociado a pv1Esp. (Cuatro niveles)"
       Espnvl2     = "Nivel de logro en Espaol. Asociado a pv2Esp. (Cuatro niveles)"
       Espnvl3     = "Nivel de logro en Espaol. Asociado a pv3Esp. (Cuatro niveles)"
       Espnvl4     = "Nivel de logro en Espaol. Asociado a pv4Esp. (Cuatro niveles)"
       Espnvl5     = "Nivel de logro en Espaol. Asociado a pv5Esp. (Cuatro niveles)"
       Espnvlb1    = "Identifica si el alumno pertenece al menos al nivel bsico de logro en Espaol. Asociado a pv1Esp."
       Espnvlb2    = "Identifica si el alumno pertenece al menos al nivel bsico de logro en Espaol. Asociado a pv2Esp."
       Espnvlb3    = "Identifica si el alumno pertenece al menos al nivel bsico de logro en Espaol. Asociado a pv3Esp."
       Espnvlb4    = "Identifica si el alumno pertenece al menos al nivel bsico de logro en Espaol. Asociado a pv4Esp."
       Espnvlb5    = "Identifica si el alumno pertenece al menos al nivel bsico de logro en Espaol. Asociado a pv5Esp."
       wvarstrr    = "Identificador del pseudoestrato (1 a 80) definido para el clculo de errores estndar con el mtodo de remuestreo BRR"
       w_fstr1     = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
       w_fstr2     = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
       w_fstr3     = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
       w_fstr4     = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
       w_fstr5     = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
       w_fstr6     = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
       w_fstr7     = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
       w_fstr8     = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
       w_fstr9     = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
       w_fstr10    = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
       w_fstr11    = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
       w_fstr12    = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
       w_fstr13    = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
       w_fstr14    = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
       w_fstr15    = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
       w_fstr16    = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
       w_fstr17    = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
       w_fstr18    = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
       w_fstr19    = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
       w_fstr20    = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
       w_fstr21    = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
       w_fstr22    = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
       w_fstr23    = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
       w_fstr24    = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
       w_fstr25    = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
       w_fstr26    = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
       w_fstr27    = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
       w_fstr28    = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
       w_fstr29    = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
       w_fstr30    = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
       w_fstr31    = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
       w_fstr32    = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
       w_fstr33    = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
       w_fstr34    = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
       w_fstr35    = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
       w_fstr36    = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
       w_fstr37    = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
       w_fstr38    = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
       w_fstr39    = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
       w_fstr40    = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
       w_fstr41    = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
       w_fstr42    = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
       w_fstr43    = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
       w_fstr44    = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
       w_fstr45    = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
       w_fstr46    = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
       w_fstr47    = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
       w_fstr48    = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
       w_fstr49    = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
       w_fstr50    = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
       w_fstr51    = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
       w_fstr52    = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
       w_fstr53    = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
       w_fstr54    = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
       w_fstr55    = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
       w_fstr56    = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
       w_fstr57    = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
       w_fstr58    = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
       w_fstr59    = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
       w_fstr60    = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
       w_fstr61    = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
       w_fstr62    = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
       w_fstr63    = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
       w_fstr64    = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
       w_fstr65    = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
       w_fstr66    = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
       w_fstr67    = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
       w_fstr68    = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
       w_fstr69    = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
       w_fstr70    = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
       w_fstr71    = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
       w_fstr72    = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
       w_fstr73    = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
       w_fstr74    = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
       w_fstr75    = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
       w_fstr76    = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
       w_fstr77    = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
       w_fstr78    = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
       w_fstr79    = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
       w_fstr80    = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
   ;

   FORMAT
       nacional           1.
       escuela            4.
       id_ent             id_entF.
       nom_ent            $char19.
       id_mod             id_modF.
       mod                $modF.
       entest             $char6.
       alumno             5.
       id_instr           $char15.
       sexo               sexoF.
       edad               edadF.
       edadc              edadcF.
       edad1sep           edad1sF.
       edad1sepc          edad1scF.
       edadn              edadnF.
       edad_ac            edad_acF.
       mes_nac            mes_nacF.
       docente            docenteF.
       ela_01             ela1_10F.
       ela_02             ela1_10F.
       ela_03             ela1_10F.
       ela_04             ela1_10F.
       ela_05             ela1_10F.
       ela_06             ela1_10F.
       ela_07             ela1_10F.
       ela_08             ela1_10F.
       ela_09             ela1_10F.
       elb_01             ela1_10F.
       elb_02             ela1_10F.
       elb_03             ela1_10F.
       elb_04             ela1_10F.
       elb_05             ela1_10F.
       elb_06             ela1_10F.
       elb_07             ela1_10F.
       elb_08             ela1_10F.
       elb_09             ela1_10F.
       elc_01             ela1_10F.
       elc_02             ela1_10F.
       elc_03             ela1_10F.
       elc_04             ela1_10F.
       elc_05             ela1_10F.
       elc_06             ela1_10F.
       elc_07             ela1_10F.
       elc_08             ela1_10F.
       elc_09             ela1_10F.
       eld_01             ela1_10F.
       eld_02             ela1_10F.
       eld_03             ela1_10F.
       eld_04             ela1_10F.
       eld_05             ela1_10F.
       eld_06             ela1_10F.
       eld_07             ela1_10F.
       eld_08             ela1_10F.
       eld_09             ela1_10F.
       eld_10             ela1_10F.
       wvarstrr           2.
   ;


/**************************************************************************
/*  Definicin de valores perdidos
/*   .I o I = Respuesta invlida (El alumno copi la respuesta a sus compaeros).
/*   .N o N = No Administrado o no alcanzado.
/*   .M o M = Respuesta Mltiple.
/*   .S o S = Respuesta omitida (No contestado).
/*************************************************************************/
   IF  sexo = 8 THEN  sexo = .M;
   IF  edad_ac = 98 THEN  edad_ac = .M;
   IF  mes_nac = 98 THEN  mes_nac = .M;

   ARRAY perdidos1(4)  sexo edadc edad1sepc edadn;
   DO  i=1 TO 4;
         IF perdidos1{i}=9 THEN  perdidos1{i}= .S;
   END;

   ARRAY perdidos2(4)  edad edad1sep edad_ac mes_nac;
   DO  i=1 TO 4;
         IF perdidos2{i}=99 THEN  perdidos2{i}= .S;
   END;

   IF  docente = 99999 THEN  docente = .S;

   ARRAY perdidos3(37)
                   ela_01 ela_02 ela_03 ela_04 ela_05 ela_06 ela_07 ela_08 ela_09 elb_01
                   elb_02 elb_03 elb_04 elb_05 elb_06 elb_07 elb_08 elb_09 elc_01 elc_02
                   elc_03 elc_04 elc_05 elc_06 elc_07 elc_08 elc_09 eld_01 eld_02 eld_03
                   eld_04 eld_05 eld_06 eld_07 eld_08 eld_09 eld_10;

   DO  i=1 TO 37;
          IF perdidos3{i} = 5   THEN  perdidos3{i} = .I;
          IF perdidos3{i} = 7   THEN  perdidos3{i} = .N;
   END;

   drop i;
RUN;



